@@ -1,9 +1,6 @@
 # -*- encoding=utf-8 -*-
 import re
-import os
 import sys
-import ruamel.yaml
-from urllib.parse import urljoin
 import requests
 from scrapy import Selector
 from utils import bytes_to_html
